Documentation
¶
Index ¶
Constants ¶
const (
DefaultQuantile = 0.95 // 95th percentile
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Appender ¶
type Appender interface {
// AppendGraph performs the appender work on the provided traffic map. The map
// may be initially empty. An appender is allowed to add or remove map entries.
AppendGraph(trafficMap graph.TrafficMap, namespace string)
}
Appender is implemented by any code offering to append a service graph with supplemental information. On error the appender should panic and it will be handled as an error response.
type DeadNodeAppender ¶ added in v0.6.0
type DeadNodeAppender struct {
// contains filtered or unexported fields
}
DeadNodeAppender is responsible for removing from the graph unwanted nodes:
- nodes for which there is no traffic reported and the related schema is missing (presumably removed from K8S). (kiali-621)
- service nodes for which there is no incoming error traffic and no outgoing edges (kiali-1326). Kiali-1526 adds an exclusion to this rule. Egress is a special terminal service node and we want to show it even if it has no incoming traffic for the time period.
func (DeadNodeAppender) AppendGraph ¶ added in v0.6.0
func (a DeadNodeAppender) AppendGraph(trafficMap graph.TrafficMap, _ string)
AppendGraph implements Appender
type IstioAppender ¶
type IstioAppender struct{}
func (IstioAppender) AppendGraph ¶
func (a IstioAppender) AppendGraph(trafficMap graph.TrafficMap, namespace string)
AppendGraph implements Appender
type ResponseTimeAppender ¶
type ResponseTimeAppender struct {
Duration time.Duration
GraphType string
InjectServiceNodes bool
IncludeIstio bool
Quantile float64
QueryTime int64 // unix time in seconds
}
ResponseTimeAppender is responsible for adding responseTime information to the graph. ResponseTime is represented as a percentile value. The default is 95th percentile, which means that 95% of requests executed in no more than the resulting milliseconds.
func (ResponseTimeAppender) AppendGraph ¶
func (a ResponseTimeAppender) AppendGraph(trafficMap graph.TrafficMap, namespace string)
AppendGraph implements Appender
type SecurityPolicyAppender ¶ added in v0.6.0
type SecurityPolicyAppender struct {
Duration time.Duration
GraphType string
IncludeIstio bool
QueryTime int64 // unix time in seconds
}
SecurityPolicyAppender is responsible for adding securityPolicy information to the graph. The appender currently reports only mutual_tls security although is written in a generic way.
func (SecurityPolicyAppender) AppendGraph ¶ added in v0.6.0
func (a SecurityPolicyAppender) AppendGraph(trafficMap graph.TrafficMap, namespace string)
AppendGraph implements Appender
type SidecarsCheckAppender ¶
func (SidecarsCheckAppender) AppendGraph ¶
func (a SidecarsCheckAppender) AppendGraph(trafficMap graph.TrafficMap, _ string)
AppendGraph implements Appender
type UnusedNodeAppender ¶ added in v0.6.0
type UnusedNodeAppender struct {
GraphType string // This appender does not operate on service graphs because it adds workload nodes.
IsNodeGraph bool // This appender does not operate on node detail graphs because we want to focus on the specific node.
}
func (UnusedNodeAppender) AppendGraph ¶ added in v0.6.0
func (a UnusedNodeAppender) AppendGraph(trafficMap graph.TrafficMap, namespace string)
AppendGraph implements Appender